"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _a, _b, _c, _d;
Object.defineProperty(exports, "__esModule", { value: true });
process.on("uncaughtException", error => {
    if (process.env.DEBUG === "true") {
        throw error;
    }
    console.error(error.message);
});
const arg_1 = __importDefault(require("arg"));
const chalk_1 = __importDefault(require("chalk"));
const file_1 = __importDefault(require("./file"));
const command_1 = __importDefault(require("./command"));
const utils_1 = require("./utils");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const pkg = require("../package.json");
const args = arg_1.default({
    // Types
    "--file": [String],
    "--help": Boolean,
    "--version": Boolean,
    "--split-horizontally": Boolean,
    "--split-vertically": Boolean,
    "--terminalApp": String,
    "--cd": String,
    // Aliases
    "-v": "--version",
    "-h": "--help",
    "--split": "--split-vertically"
}, { permissive: false, argv: process.argv.slice(2) });
const help = chalk_1.default `
  {bold.magenta newsh} - [${pkg.version}] Running files/scripts in a new shell

  {bold USAGE}
    {bold $} {cyan newsh} "npx jest --watch" && yarn start
    {bold $} {cyan newsh} --file path/to/script
    {bold $} {cyan newsh} --split "npx jest --watch"
    {bold $} {cyan newsh} --split-horizontally "npx tsc --watch"
    {bold $} {cyan newsh} --cd ~
    {bold $} {cyan newsh} --help
    {bold $} {cyan newsh} --version
  
  {bold OPTIONS}
    -h, --help              Shows this help message
    -v, --version           Displays the current version of newsh
  
    --split-vertically      Split the screen vertically instead of opening a new one (iTerm2 & tmux only)
    --split-horizontally    Split the screen horizontally instead of opening a new one (iTerm2 & tmux only)
    --split                 Alias for --split-vertically
    --terminalApp           Choose a specific terminal app to use (e.g. iTerm.app)
    --cd                    Open the new shell in the specified directory
`;
if (args["--help"]) {
    console.log(help);
    process.exit(0);
}
if (args["--version"]) {
    console.log(pkg.version);
    process.exit(0);
}
const files = args["--file"];
const scripts = args._;
if ((!files || ((_a = files) === null || _a === void 0 ? void 0 : _a.length) === 0) && (!scripts || ((_b = scripts) === null || _b === void 0 ? void 0 : _b.length) === 0)) {
    throw new utils_1.ErrorMessage("please provide a file/command to run");
}
const splitDirection = args["--split-vertically"]
    ? "vertically"
    : args["--split-horizontally"]
        ? "horizontally"
        : undefined;
const initialOptions = {
    env: {},
    cwd: undefined,
    cd: args["--cd"],
    split: !!splitDirection,
    splitDirection,
    terminalApp: args["--terminalApp"]
};
(_c = scripts) === null || _c === void 0 ? void 0 : _c.forEach(script => command_1.default(script, initialOptions));
(_d = files) === null || _d === void 0 ? void 0 : _d.forEach(filePath => file_1.default(filePath, initialOptions));
//# sourceMappingURL=cli.js.map