"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const tempy_1 = __importDefault(require("tempy"));
const fs_1 = __importDefault(require("fs"));
const launchTerminal_1 = __importDefault(require("./launchTerminal"));
const normalize_1 = __importDefault(require("./normalize"));
function commandWindows(script, options) {
    const launchFilePath = path_1.default.join(tempy_1.default.directory(), "launchTerminal.bat");
    const environmentParams = [];
    const { env } = options;
    if (env) {
        for (const paramKey in env) {
            environmentParams.push(`set ${paramKey}=${env[paramKey]}`);
        }
    }
    const batFile = `
@echo off
${environmentParams.join("\n")}
cmd.exe @cmd /k ${script}
pause
exit`;
    fs_1.default.writeFileSync(launchFilePath, batFile);
    fs_1.default.chmodSync(launchFilePath, 0o751);
    launchTerminal_1.default(launchFilePath, options);
}
// There is a bug when npm create environment params which contains `"`
// Usually when trying to take npm scripts which contains `\"` in them
// (e.g. VAR="npm_package_scripts_test_watch="tsc --watch"")
// They clash with the `"` used for the definition of the variable in bash
// This is a best effort to assign them by changing them to `'`
function escapeDoubleQuotes(value) {
    var _a;
    return (_a = value) === null || _a === void 0 ? void 0 : _a.replace(/"/g, `'`);
}
function commandUnix(script, options) {
    const launchFilePath = path_1.default.join(tempy_1.default.directory(), "launchTerminal");
    const { env, cd } = options;
    const environmentParams = [];
    if (env) {
        for (const paramKey in env) {
            if (env[paramKey]) {
                environmentParams.push(`${paramKey}="${escapeDoubleQuotes(env[paramKey])}" `);
            }
        }
    }
    const moveToDirCommand = `cd ${cd};`;
    const scriptWithMovePrefix = moveToDirCommand + environmentParams.join("") + script;
    fs_1.default.writeFileSync(launchFilePath, scriptWithMovePrefix);
    // add execute permissions (-rwxr-xr-x)
    fs_1.default.chmodSync(launchFilePath, 0o751);
    launchTerminal_1.default(launchFilePath, options);
}
function command(script, initialOptions = {}) {
    const options = normalize_1.default(initialOptions);
    const isWindows = /^win/.test(process.platform);
    const nodeModulesBin = path_1.default.join(options.cwd, "node_modules", ".bin");
    if (fs_1.default.existsSync(nodeModulesBin)) {
        if (isWindows) {
            options.env.Path = `${nodeModulesBin}:${options.env.Path}`;
        }
        else {
            options.env.PATH = `${nodeModulesBin}:${options.env.PATH}`;
        }
    }
    if (!isWindows) {
        commandUnix(script, options);
    }
    else {
        commandWindows(script, options);
    }
}
exports.default = command;
//# sourceMappingURL=command.js.map