"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const execa_1 = __importDefault(require("execa"));
const path_1 = __importDefault(require("path"));
const child_process_1 = require("child_process");
exports.windows = (execFilePath, options) => {
    execa_1.default.sync("cmd.exe", ["/C", path_1.default.join(__dirname, "../scripts/windows.bat")], {
        detached: true,
        stdio: "ignore",
        env: {
            FILE_PATH: execFilePath,
            CD: options.cd
        }
    });
};
exports.linux = (execFilePath, options) => {
    try {
        execa_1.default.sync(options.terminalApp, ["-e", `sh ${execFilePath}`], {
            detached: true
        });
    }
    catch (error) {
        execa_1.default.sync("sh", [execFilePath]);
    }
};
exports.mac = (execFilePath, options) => {
    try {
        execa_1.default.sync("open", ["-a", options.terminalApp, execFilePath]);
    }
    catch (error) {
        execa_1.default.sync("open", [execFilePath]);
    }
};
exports.iterm = (execFilePath, options) => {
    try {
        execa_1.default.sync(path_1.default.join(__dirname, "../scripts/iterm.sh"), [execFilePath], Object.assign(Object.assign({}, options.env), { env: { SPLIT_DIRECTION: options.splitDirection } }));
        return;
    }
    catch (error) {
        exports.mac(execFilePath, options);
    }
};
exports.tmux = (execFilePath, options) => {
    try {
        const tmuxSplitDirection = options.splitDirection === "vertically" ? "h" : "v";
        execa_1.default.sync(path_1.default.join(__dirname, "../scripts/tmux.sh"), [execFilePath], Object.assign(Object.assign({}, options.env), { env: { SPLIT_DIRECTION: tmuxSplitDirection } }));
        return;
    }
    catch (error) {
        if (options.terminalApp === "iTerm.app") {
            exports.iterm(execFilePath, options);
        }
        else {
            exports.mac(execFilePath, options);
        }
    }
};
exports.conEmu = (execFilePath, options) => {
    let splitSuffix = "";
    if (options.split) {
        const conEmuSplitDirection = options.splitDirection === "vertically" ? "H" : "V";
        splitSuffix = `:s${conEmuSplitDirection}`;
    }
    try {
        child_process_1.exec(`cmd.exe -new_console${splitSuffix}:b:d:"${options.cd}" /k ${execFilePath}`);
    }
    catch (error) {
        exports.windows(execFilePath, options);
    }
};
//# sourceMappingURL=launchers.js.map